@@ -456,22 +456,19 @@ def dlpack_2023_12(api_version):
         set_array_api_strict_flags(api_version=api_version)
 
     a = asarray([1, 2, 3], dtype=int8)
-    # Never an error
+
+    # Do not error
     a.__dlpack__()
+    a.__dlpack__(dl_device=CPU_DEVICE)
+    a.__dlpack__(dl_device=None)
+    a.__dlpack__(max_version=(1, 0))
+    a.__dlpack__(max_version=None)
+    a.__dlpack__(copy=False)
+    a.__dlpack__(copy=True)
+    a.__dlpack__(copy=None)
 
-
-    exception = NotImplementedError if api_version >= '2023.12' else ValueError
-    pytest.raises(exception, lambda:
-                  a.__dlpack__(dl_device=CPU_DEVICE))
-    pytest.raises(exception, lambda:
-                  a.__dlpack__(dl_device=None))
-    pytest.raises(exception, lambda:
-                  a.__dlpack__(max_version=(1, 0)))
-    pytest.raises(exception, lambda:
-                  a.__dlpack__(max_version=None))
-    pytest.raises(exception, lambda:
-                    a.__dlpack__(copy=False))
-    pytest.raises(exception, lambda:
-                    a.__dlpack__(copy=True))
-    pytest.raises(exception, lambda:
-                    a.__dlpack__(copy=None))
+    x = np.from_dlpack(a)
+    assert isinstance(x, np.ndarray)
+    assert x.dtype == np.int8
+    assert x.shape == (3,)
+    assert np.all(x == np.asarray([1, 2, 3]))
